yakumo.nova.v2.availability_zone.Manager

Package yakumo :: Package nova :: Package v2 :: Module availability_zone :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for availability zones in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for availability zones in Compute API v2

Instance Methods | [hide private]
yakumo.base.Resource |
get(self, name) Aquire an existing resource object | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``name``'``,` `'``zoneName``'``,` <yakumo.mapper.NoopClass`...``
| _hidden_methods = ``[``'``create``'``,` `'``update``'``]``
| _id_attr = ``'``name``'``
| _json_resource_key = ``'``availabilityZoneInfo``'``
| _json_resources_key = ``'``availabilityZoneInfo``'``
| _url_resource_path = ``'``/os-availability-zone``'``
| _url_resource_list_path = ``'``/os-availability-zone/detail``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get(self, name) | source code
Aquire an existing resource object Parameters: `id` - ID Returns: yakumo.base.Resource Resource object Overrides: base.Manager.get (inherited documentation)

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('name',
        'zoneName',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('status',
        'zoneState',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('hosts',
        'hosts',
      ...